@@ -9,18 +9,18 @@ class TestOneToOne(object):
 
     def test_simple(self):
         class A(Entity):
-            name = Field(Unicode(60))
+            name = Field(String(60))
             b = OneToOne('B')
 
         class B(Entity):
-            name = Field(Unicode(60))
+            name = Field(String(60))
             a = ManyToOne('A')
 
         setup_all(True)
 
         b1 = B(name='b1', a=A(name='a1'))
 
-        session.flush()
+        session.commit()
         session.clear()
 
         b = B.query.one()
